sqlobject.tests.test_paste module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_paste module

class `sqlobject.tests.test_paste.` `NameOnly`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = name_only
  property `name`
  `q` = name_only
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_paste.NameOnly`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'name_only'

`sqlobject.tests.test_paste.` `makeapp`(abort=False, begin=False, fail=False)

`sqlobject.tests.test_paste.` `makestack`(abort=False, begin=False, fail=False, **kw)

`sqlobject.tests.test_paste.` `names`()

`sqlobject.tests.test_paste.` `runapp`(**kw)

`sqlobject.tests.test_paste.` `setup`()

`sqlobject.tests.test_paste.` `test_fail`()

`sqlobject.tests.test_paste.` `test_other`()